package com.todottl.ui.screen

import androidx.compose.foundation.Image
import androidx.compose.foundation.background
import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.size
import androidx.compose.foundation.lazy.LazyColumn
import androidx.compose.foundation.lazy.items
import androidx.compose.foundation.lazy.rememberLazyListState
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.material3.Button
import androidx.compose.material3.Card
import androidx.compose.material3.CardDefaults
import androidx.compose.material3.Checkbox
import androidx.compose.material3.HorizontalDivider
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.runtime.LaunchedEffect
import androidx.compose.runtime.derivedStateOf
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.setValue
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.draw.alpha
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.layout.ContentScale
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.tooling.preview.Preview
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import androidx.navigation.NavController
import androidx.navigation.compose.rememberNavController
import com.todottl.R
import com.todottl.data.Constant
import com.todottl.data.RouteConfig
import com.todottl.ui.theme.TodoTTLTheme

@Composable
fun IndexScreen(navController: NavController) {
    var isButtonVisible by remember { mutableStateOf(true) }
    val listState = rememberLazyListState()

    // 根据滚动状态来更新按钮的可见性
    LaunchedEffect(remember { derivedStateOf { listState.firstVisibleItemIndex } }) {
        isButtonVisible = listState.firstVisibleItemIndex == 0
    }

    Box(
        modifier = Modifier
            .fillMaxSize()
            .background(Color(0xFFF1F5F9))
    ) {
        // 背景图
        Image(
            modifier = Modifier
                .fillMaxWidth()
                .height(222.dp),
            contentScale = ContentScale.Crop,
            painter = painterResource(R.mipmap.header),
            contentDescription = "Header"
        )
        Text(
            "日期",
            fontSize = 16.sp,
            fontWeight = FontWeight.Bold,
            color = Color.White,
            modifier = Modifier
                .align(Alignment.TopCenter)
                .padding(top = 36.dp)
        )

        Text(
            "My Todo List",
            fontSize = 30.sp,
            fontWeight = FontWeight.Bold,
            color = Color.White,
            modifier = Modifier
                .align(Alignment.TopCenter)
                .padding(top = 96.dp)
        )

        Card(
            modifier = Modifier
                .align(Alignment.TopCenter)
                .padding(top = 158.dp, start = 16.dp, end = 16.dp),
            colors = CardDefaults.cardColors(containerColor = Color.White),
            shape = RoundedCornerShape(16.dp)
        ) {
            LazyColumn(state = listState) {
                items(Constant.imageList) {
                    TodoItem(it)
                    if (Constant.imageList.indexOf(it) != Constant.imageList.lastIndex) {
                        HorizontalDivider(
                            modifier = Modifier
                                .fillMaxWidth()
                        )
                    }
                }
            }
        }
        if (isButtonVisible) {
            Button(
                onClick = {
                    navController.navigate(RouteConfig.ADD)
                },
                modifier = Modifier
                    .align(Alignment.BottomCenter)
                    .padding(start = 16.dp, end = 16.dp, bottom = 24.dp)
                    .fillMaxWidth()
                    .height(56.dp),
                shape = RoundedCornerShape(50.dp)
            ) {
                Text(text = "Add New Task")
            }
        }
    }
}

@Composable
fun TodoItem(index: Int) {
    Row(
        modifier = Modifier
            .height(80.dp)
            .padding(16.dp),
        verticalAlignment = Alignment.CenterVertically
    ) {
        Row(
            modifier = Modifier
                .weight(1f)
                .alpha(if (index % 2 == 1) 0.5f else 1f),
            verticalAlignment = Alignment.CenterVertically
        ) {
            Image(
                painter = painterResource(index),
                modifier = Modifier.size(48.dp),
                contentDescription = ""
            )
            Column(
                modifier = Modifier
                    .fillMaxSize()
                    .padding(start = 12.dp),
                verticalArrangement = Arrangement.Center
            ) {
                Text(
                    "Today",
                    fontSize = 16.sp,
                    fontWeight = FontWeight.Bold
                )
                Text(
                    "0/0",
                    fontSize = 14.sp,
                    modifier = Modifier.alpha(0.7f)
                )
            }
        }
        Checkbox(
            checked = index % 2 == 1,
            modifier = Modifier.size(24.dp),
            onCheckedChange = {},
        )
    }
}

@Preview(showBackground = true)
@Composable
fun IndexScreenPreview() {
    val navController = rememberNavController()
    TodoTTLTheme {
        IndexScreen(navController)
    }
}